@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.workflows_v1beta.types import workflows
@@ -74,14 +74,14 @@ class ListWorkflowsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[workflows.ListWorkflowsResponse]:
+    def pages(self) -> Iterator[workflows.ListWorkflowsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[workflows.Workflow]:
+    def __iter__(self) -> Iterator[workflows.Workflow]:
         for page in self.pages:
             yield from page.workflows
 
@@ -136,14 +136,14 @@ class ListWorkflowsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[workflows.ListWorkflowsResponse]:
+    async def pages(self) -> AsyncIterator[workflows.ListWorkflowsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[workflows.Workflow]:
+    def __aiter__(self) -> AsyncIterator[workflows.Workflow]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.workflows:
